@@ -18,6 +18,7 @@ async function isAndroid() {
     }
 }
 
+const isMobile = isAndroid; // TODO deprecate old name? note sure
 
 // TODO ugh. en-GB etc can't be parsed by Date.parse afterwards...
 
@@ -113,7 +114,7 @@ export async function searchAround(timestamp: number): Promise<Visits> {
 }
 
 function getDelayMs(/*url*/) {
-    return 10 * 60 * 1000; // TODO do something smarter... for some domains we want it to be without delay
+    return 10 * 1000;
 }
 
 const LOCAL_TAG = 'local';
@@ -245,10 +246,21 @@ async function updateState (tab: chrome$Tab) {
     }
 
     const opts = await get_options_async();
-    // TODO this should be executed as a single block?
-    await chromeTabsExecuteScriptAsync(tabId, {file: 'sidebar.js'});
-    await chromeTabsInsertCSS(tabId, {file: 'sidebar-outer.css'});
-    await chromeTabsInsertCSS(tabId, {code: opts.position_css});
+    // TODO this should be executed as an atomic block?
+
+    const inject = () => chromeTabsExecuteScriptAsync(tabId, {file: 'sidebar.js'})
+    // TODO hmm. in theory script and CSS injections commute, but css order on the othe hand might matter?
+    // not sure, but using deferred promises just in case
+          .then(() => chromeTabsInsertCSS(tabId, {file: 'sidebar-outer.css'}))
+          .then(() => chromeTabsInsertCSS(tabId, {code: opts.position_css}));
+
+
+    // NOTE: if the page is unreachable, we can't inject stuf in it
+    // not sure how to detect it? tab doesn't have any interesting attributes
+    // firefox sets tab.title to "Server Not Found"? (TODO also see isOk logic below)
+    // TODO in this case, could set browser action to open a new tab (i.e. search) or something?
+    await defensify(inject, 'sidebar injection')();
+    // TODO crap, at first I forgot () at the end, and flow didn't complain which resulted in flakiness wtf??
 
     const visits = await getVisits(url);
     let {icon, title, text} = getIconStyle(visits);
@@ -286,14 +298,23 @@ async function updateState (tab: chrome$Tab) {
         }
     }
 
-    // TODO ok, only show it if there are visits? and only on android?
-    // TODO write that icon can't be changed on android
-
-    if (icon === 'images/ic_visited_48.png') { // ugh. pretty hacky
-        // TODO do I need to hide?
-        if (chrome.pageAction) {
-            // TODO make dependent on options?
-            chrome.pageAction.show(tabId);
+    /* NOTE: few things here
+     * 1. browser action is only shown in the 'settings on android' (and no icon), so we're using page action
+     * 2. page action icon can't be changed on android, so we're only showing it when there are contexts
+     *    otherwise, we're relying on 'mobile_sidebar_injector' to open the sidebar
+     */
+    if (await isMobile()) {
+        const action = chrome.pageAction;
+        const interesting = [
+            'images/ic_visited_48.png',
+            'images/ic_relatives_48.png',
+        ].includes(icon); // FIXME meh. hacky
+        // TODO make dependent on options?
+        if (interesting) {
+            action.show(tabId);
+        } else {
+            // not sure if this is really needed, but I feel like it persists otherwise on android
+            action.hide(tabId);
         }
     }
 
@@ -309,19 +330,15 @@ async function updateState (tab: chrome$Tab) {
         // TODO and show system wide notification instead of tab notification?
         // https://stackoverflow.com/questions/32761782/can-a-chrome-extension-run-code-on-a-chrome-error-page-i-e-err-internet-disco
         // https://stackoverflow.com/questions/37093152/unchecked-runtime-lasterror-while-running-tabs-executescript-cannot-access-cont
-        // a little hacky, but kinda works?
+        // a little hacky, but kinda works? in Firefox too apparently
         const isOk = (await chromeTabsGet(tabId)).favIconUrl != 'chrome://global/skin/icons/warning.svg';
 
         // TODO maybe store last time we showed it so it's not that annoying... although I definitely need js popup notification.
         const locs = visits.self_contexts().map(l => l == null ? null : l.title);
         if (locs.length !== 0) {
             const msg = `${locs.length} contexts!\n${locs.join('\n')}`;
-            if (isOk) {
-                if (opts.contexts_popup_on) {
-                    await showTabNotification(tabId, msg);
-                }
-            } else {
-                notify(msg);
+            if (opts.contexts_popup_on) {
+                await showTabNotification(tabId, msg);
             }
         }
 
@@ -502,6 +519,7 @@ chrome.tabs.onUpdated.addListener(defensify(async (tabId, info, tab) => {
         return;
     }
 
+    // TODO make logging optional? not sure if there are any downsides
     if (ignored(url)) {
         linfo('onUpdated: ignored explicitly %s', url);
         return;
@@ -547,8 +565,11 @@ chrome.tabs.onUpdated.addListener(defensify(async (tabId, info, tab) => {
 }, 'onUpdated'));
 
 
-async function getActiveTab(): Promise<chrome$Tab> {
-    const tabs = await chromeTabsQueryAsync({'active': true});
+export async function getActiveTab(): Promise<chrome$Tab> {
+    const tabs = await chromeTabsQueryAsync({
+        'currentWindow': true,
+        'active': true,
+    });
     // TODO can it be empty at all??
     if (tabs.length > 1) {
         console.error("Multiple active tabs: %o", tabs); // TODO handle properly?
@@ -610,11 +631,9 @@ const onMessageCallback = async (msg) => { // TODO not sure if should defensify
         // return true; // this is important!! otherwise message will not be sent?
     } else if (method == Methods.SEARCH_VISITS_AROUND) {
         // TODO reuse handleOpenSearch?
-        // TODO careful about the type?
-        const utc_ts = msg.utc_timestamp;
+        const utc_timestamp_s: number = msg.utc_timestamp_s;
         const params = new URLSearchParams();
-        // TODO str??
-        params.append('timestamp', utc_ts);
+        params.append('utc_timestamp', utc_timestamp_s.toString());
         const search_url = chrome.extension.getURL('search.html') + '?' + params.toString();
         chrome.tabs.create({'url': search_url});
     } else if (method == Methods.MARK_VISITED) {
@@ -633,27 +652,30 @@ const onMessageCallback = async (msg) => { // TODO not sure if should defensify
    popup is available for pageAction?? can use it for blacklisting/search?
 */
 async function registerActions() {
+    // NOTE: on mobile, this sets action for both icon (if it's displayed) and in the menu
     for (const action of (await actions())) {
         // $FlowFixMe
-        action.onClicked.addListener(defensify(async tab => {
-            const url = unwrap(tab.url);
-            const tid = unwrap(tab.id);
-            if (ignored(url)) {
-                // TODO tab notification?
-                notify(`${url} can't be handled`);
-                return;
-            }
-            const blacklist = await Blacklist_get();
-            const bl = await blacklist.contains(url);
-            if (bl != null) {
-                await showBlackListedNotification(tid, new Blacklisted(url, bl));
-                // TODO show popup; suggest to whitelist?
-            } else {
-                // TODO ugh. messy
-                await chromeTabsExecuteScriptAsync(tid, {file: 'sidebar.js'});
-                await chromeTabsExecuteScriptAsync(tid, {code: 'toggleSidebar();'});
-            }
-        }, 'action.onClicked'));
+        action.onClicked.addListener(defensify(injectSidebar, 'action.onClicked'));
+    }
+}
+
+export async function injectSidebar(tab: chrome$Tab) {
+    const url = unwrap(tab.url);
+    const tid = unwrap(tab.id);
+    if (ignored(url)) {
+        // TODO tab notification?
+        notify(`${url} can't be handled`);
+        return;
+    }
+    const blacklist = await Blacklist_get();
+    const bl = await blacklist.contains(url);
+    if (bl != null) {
+        await showBlackListedNotification(tid, new Blacklisted(url, bl));
+        // TODO show popup; suggest to whitelist?
+    } else {
+        // TODO ugh. messy
+        await chromeTabsExecuteScriptAsync(tid, {file: 'sidebar.js'});
+        await chromeTabsExecuteScriptAsync(tid, {code: 'toggleSidebar();'});
     }
 }
 
