@@ -1,6 +1,7 @@
 from pathlib import Path
 from typing import List, Optional, Union, NamedTuple
 import importlib.util
+import warnings
 
 import pytz
 
@@ -9,16 +10,34 @@ from .common import PathIsh, get_tmpdir
 
 class Config(NamedTuple):
     OUTPUT_DIR: PathIsh
-    INDEXERS: List
+    # TODO remove default from sources once migrated
+    SOURCES: List = []
+    INDEXERS: List = []
     CACHE_DIR: Optional[PathIsh] = None
     FILTERS: List[str] = []
 
+    @property
+    def sources(self):
+        if self.INDEXERS is not None:
+            warnings.warn("'INDEXERS' is deprecated. Please use 'SOURCES'!", DeprecationWarning)
+
+        res = self.SOURCES or self.INDEXERS
+        # TODO enable it?
+        # assert len(res) > 0, "Expected some sources"
+        return res
+
     @property
     def cache_dir(self) -> Path:
         cd = self.CACHE_DIR
         # TODO maybe do not use cache if it's none?
         assert cd is not None
-        return Path(cd)
+        res = Path(cd)
+        res.mkdir(exist_ok=True) # TODO not sure about parents=True
+        return res
+
+    @property
+    def output_dir(self) -> Path:
+        return Path(self.OUTPUT_DIR)
 
 
 instance: Optional[Config] = None
