@@ -1,14 +1,13 @@
-from pathlib import Path
-from typing import Iterator, Optional
+'''
+Uses [[https://github.com/karlicoss/HPI][HPI]] for the messages data.
+'''
 
-from ..common import Extraction, get_logger, Visit, Loc, PathIsh, extract_urls
+from ..common import Results, Visit, Loc, extract_urls
 
 from my.fbmessenger import messages
 
 
-# TODO rename Extraction to smth shorter? even Result is good enough?
-def index() -> Iterator[Extraction]:
-    # TODO add db path?
+def index() -> Results:
     for m in messages():
         text = m.text
         if text is None:
