@@ -1,16 +1,17 @@
-from typing import Iterator, Optional
-
-from ..common import Extraction, get_logger, Visit, Loc, PathIsh
+'''
+Uses HPI [[https://github.com/karlicoss/HPI/blob/master/doc/MODULES.org#myinstapaper][instapaper]] module
+'''
+from ..common import Results, get_logger, Visit, Loc
 
 import my.instapaper as ip
 
 
-def index() -> Iterator[Extraction]:
+def index() -> Results:
     logger = get_logger()
 
     for p in ip.pages():
-        bm = p.bookmark
-        hls = p.highlights
+        bm = p.bookmark # type: ignore[attr-defined]
+        hls = p.highlights # type: ignore[attr-defined]
 
         def visit(**kwargs):
             return Visit(
@@ -25,7 +26,7 @@ def index() -> Iterator[Extraction]:
                 locator=Loc.make(title='instapaper', href=bm.instapaper_link),
             )
         else:
-            for hl in p.highlights:
+            for hl in p.highlights: # type: ignore[attr-defined]
                 cparts = [hl.text]
                 if hl.note is not None:
                     cparts.append('comment: ' + hl.note)
@@ -35,3 +36,5 @@ def index() -> Iterator[Extraction]:
                     locator=Loc.make(title='instapaper', href=hl.instapaper_link),
                 )
 
+
+# TODO mypy: properly clone repos and typecheck on CI, get rid of attr-defined ignores
