@@ -166,6 +166,7 @@ def configure(
         blacklist=None,
         notification: Optional[bool]=None,
         position: Optional[str]=None,
+        verbose_errors: bool=True,
 ):
     def set_checkbox(cid: str, value: bool):
         cb = driver.find_element_by_id(cid)
@@ -189,7 +190,9 @@ def configure(
     # if dots.is_selected() != show_dots:
     #     dots.click()
     # assert dots.is_selected() == show_dots
-    set_checkbox('verbose_errors_id', False)
+
+    # TODO not sure, should be False for demos?
+    set_checkbox('verbose_errors_id', verbose_errors)
 
     if highlights is not None:
         set_checkbox('highlight_id', highlights)
@@ -396,11 +399,12 @@ def set_position(driver, settings: str):
         # ugh... for some reason wouldn't send the keys...
         field.click()
         import pyautogui # type: ignore
-        pyautogui.press(['backspace'] * 100 + ['delete'] * 100)
-        pyautogui.typewrite(settings, interval=0.1)
+        # it usually ends up in the middle of the area...
+        pyautogui.press(['backspace'] * 500 + ['delete'] * 500)
+        pyautogui.typewrite(settings, interval=0.05)
     else:
         area = field.find_element_by_xpath('.//textarea')
-        area.send_keys([Keys.DELETE] * 500)
+        area.send_keys([Keys.DELETE] * 1000)
         area.send_keys(settings)
 
 
@@ -468,7 +472,7 @@ def test_add_to_blacklist(tmp_path, browser):
             offset = 2 # Inspect, View page source
         else:
             offset = 0
-        pyautogui.typewrite(['up'] + ['up'] * offset + ['enter'], interval=0.5)
+        pyautogui.typewrite(['up'] + ['up'] * offset + ['enter'] + ['enter'], interval=0.5)
 
         confirm('shows prompt with alert to enter pattern to block?')
         driver.switch_to.alert.accept()
@@ -491,11 +495,13 @@ def test_visits(tmp_path, browser):
 
 @uses_x
 @browsers(FF, CH)
-def test_around(tmp_path, browser):
+def test_search_around(tmp_path, browser):
+    # TODO it actually lacks a proper end-to-end test withing browser... although I do have something in automatic demos?
     test_url = "about:blank"
     with _test_helper(tmp_path, index_hypothesis, test_url, browser=browser) as h:
-        ts = int(datetime.strptime("2017-05-22T10:59:00.082375+00:00", '%Y-%m-%dT%H:%M:%S.%f%z').timestamp())
-        h.open_page(f'search.html?timestamp={ts}')
+        # TODO hmm. dunno if we want to highlight only result with the same timestamp, or the results that are 'near'??
+        ts = int(datetime.strptime("2017-05-22T10:59:12.082375+00:00", '%Y-%m-%dT%H:%M:%S.%f%z').timestamp())
+        h.open_page(f'search.html?utc_timestamp={ts}')
         confirm('you should see search results, "anthrocidal" should be highlighted red')
 
 
@@ -611,13 +617,14 @@ def test_stress(tmp_path, browser):
 @uses_x
 @browsers(FF, CH)
 def test_fuzz(tmp_path, browser):
+    # TODO ugh. this still results in 'tab permissions' pages, but perhaps because of closed tabs?
+    # dunno if it's worth fixing..
     urls = {
         'https://www.iana.org/domains/reserved': 'IANA',
         'iana.org/domains/reserved': 'IANA2',
     }
     with _test_helper(tmp_path, index_urls(urls), 'https://example.com', browser=browser) as helper:
         driver = helper.driver
-        # import ipdb; ipdb.set_trace()
         tabs = 30
         for _ in range(tabs):
             driver.find_element_by_tag_name('a').send_keys(Keys.CONTROL + Keys.RETURN)
@@ -683,3 +690,8 @@ def test_duplicate_background_pages(tmp_path, browser):
 #     at notifyError (VM2056 notifications.js:41)
 
 
+
+# TODO FIXME need to test racey conditions _while_ page is loading, results in this 'unexpected error occured'?
+
+
+# TODO shit, sometimes I have 'bindSidebarData is not defined'? with vebose errors on demo_how_did_i_get_here
