@@ -3,18 +3,13 @@ from subprocess import check_call, run
 from typing import Set, Dict, Optional, Union, Sequence, Tuple
 
 from indexer_test import populate_db
-from common import tdir, under_ci
+from common import tdir, under_ci, DATA, GIT_ROOT
 
 import pytest
 
 import platform
 system = platform.system()
 
-# TODO move to common?
-ROOT = Path(__file__).absolute().parent.parent
-
-testdata = ROOT / 'testdata'
-
 
 def index(cfg: Path):
     from promnesia.__main__ import do_index
@@ -22,7 +17,7 @@ def index(cfg: Path):
 
 
 def test_example_config(tdir):
-    example = ROOT / 'config.py.example'
+    example = GIT_ROOT / 'config.py.example'
     ex = example.read_text()
     if under_ci():
         # TODO ugh fucking hell I couldn't find a single path that has HTMLs both on macos and ubuntu
@@ -80,10 +75,10 @@ def index_urls(urls: Urls):
         cfg.write_text(f"""
 OUTPUT_DIR = '{tdir}'
 
-from promnesia.common import Source, PreVisit, Loc
+from promnesia.common import Source, Visit, Loc
 from datetime import datetime, timedelta
 indexer = Source(
-    lambda: [PreVisit(
+    lambda: [Visit(
         url=url,
         dt=datetime.min + timedelta(days=5000) + timedelta(hours=i),
         locator=Loc.make('test'),
@@ -100,6 +95,7 @@ SOURCES = [indexer]
 
 def index_hypothesis(tdir: Path):
     # TODO meh..
+    # TODO use submodule?
     hypexport_path = Path(tdir) / 'hypexport'
     check_call([
         'git',
@@ -114,20 +110,17 @@ def index_hypothesis(tdir: Path):
     cfg.write_text(f"""
 OUTPUT_DIR = '{tdir}'
 
-from promnesia.common import Indexer as I
+from promnesia.common import Source
 
 def hyp_extractor():
     import my.config
-    class hypothesis:
-        export_path = '{testdata}/hypothesis/netrights-dashboards-mockup/data/annotations.json'
-    my.config.hypothesis = hypothesis
-
-    # TODO good example for documentaion
-    from my.cfg import set_repo
-    set_repo('hypexport', '{hypexport_path}')
+    class user_config:
+        export_path = '{str(DATA)}/hypothesis/netrights-dashboards-mockup/data/*.json'
+        hypexport   = '{hypexport_path}'
+    my.config.hypothesis = user_config
 
     import promnesia.sources.hypothesis as hypi
-    return I(
+    return Source(
         hypi.index,
         src='hyp',
     )
@@ -206,3 +199,37 @@ def test_comparison(tdir: Path):
 
     assert len(list(compare_files(db, old_db))) == 1
 
+
+def test_index_many(tdir):
+    # NOTE [20200521] experimenting with promnesia.dump._CHUNK_BY
+    # inserting 100K visits
+    # value=1000: 9 seconds
+    # value=10  : 9 seconds
+    # value=1   : 18 seconds
+    # ok, I guess it's acceptable considering the alternative is crashing (too many sql variables on some systems)
+    # kinda makes sense -- I guess most overhead is coming from creating temporary lists etc?
+    cfg = tdir / 'test_config.py'
+    cfg.write_text(f"""
+from datetime import datetime, timedelta
+from promnesia import Source, Visit, Loc
+# TODO def need to allow taking in index function without having to wrap in source?
+def index():
+    for i in range(100000):
+        yield Visit(
+            url='http://whatever/page' + str(i),
+            dt=datetime.min + timedelta(days=5000) + timedelta(hours=i),
+            locator=Loc.make('test'),
+        )
+
+SOURCES = [Source(index)]
+OUTPUT_DIR = '{tdir}'
+    """)
+    index(cfg)
+    #
+    # TODO copy pasting from server; need to unify
+    engine, binder, table = _get_stuff(tdir)
+    query = table.select()
+    with engine.connect() as conn:
+        visits = [binder.from_row(row) for row in conn.execute(query)]
+
+    assert len(visits) == 100000
